--- whois.c.dist	Wed Aug 22 21:19:19 2001
+++ whois.c	Wed Aug 22 21:22:08 2001
@@ -77,6 +77,11 @@
 static void usage __P((void));
 static void whois __P((char *, struct addrinfo *, int));
 
+#if defined(__linux__) || defined(__sun__)
+char *fgetln(FILE *f, size_t *size);
+void out_of_memory();
+#endif
+
 int
 main(argc, argv)
 	int argc;
@@ -295,3 +300,57 @@
 	    "usage: whois [-adgimpQrR6] [-h hostname] name ...\n");
 	exit(EX_USAGE);
 }
+
+#if defined(__linux__) || defined(__sun__)
+
+/* Linux doesn't support fgetln() *sigh*
+** Credits of this implementation:  GED2HTML by Eugene W. Stark
+** http://www.gendex.com/ged2html/2.5b/Welcome.html
+**
+** Cygwin doesn't support it either...but it's also lacking a number
+** of other essential functions
+*/
+
+char *fgetln(FILE *f, size_t *size)
+{
+   static char *l = NULL;
+   char *lp;
+   static int max = 4;
+   int s = 0, c;
+   
+    
+   if(l == NULL) {
+     if((l = malloc(max)) == NULL)
+   	   out_of_memory();
+   }
+   if(feof(f) || ferror(f)) {
+     *size = 0;
+     return(NULL);
+   }
+   lp = l;
+   while((c = fgetc(f)) != EOF) {
+     if(s >= max-1) {
+        max = 2*max;
+        if((l = realloc(l, max)) == NULL)
+          out_of_memory();
+        lp = l + s;   
+     }
+     *lp++ = c;
+     s++;
+     if(c == '\n')
+        break;
+   }
+   *lp++ = '\0';
+   *size = s;
+   if(s == 0)
+     return(NULL);
+   return(l);
+}
+
+void out_of_memory()
+{
+  fprintf(stderr, "Insufficient memory available for processing.\n");
+  exit(1);
+}
+
+#endif
